@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package MetaCPAN::Client;
 # ABSTRACT: A comprehensive, DWIM-featured client to the MetaCPAN API
-$MetaCPAN::Client::VERSION = '1.009000';
+$MetaCPAN::Client::VERSION = '1.010000';
 use Moo;
 use Carp;
 
@@ -30,9 +30,9 @@ sub BUILDARGS {
     my ( $class, %args ) = @_;
 
     $args{'request'} ||= MetaCPAN::Client::Request->new(
-        ( ua => $args{'ua'} ) x !! $args{'ua'},
-        $args{domain}  ? ( domain => $args{domain} )   : (),
-        $args{version} ? ( version => $args{version} ) : (),
+        ( ua      => $args{ua}      )x!! $args{ua},
+        ( domain  => $args{domain}  )x!! $args{domain},
+        ( version => $args{version} )x!! $args{version},
     );
 
     return \%args;
@@ -155,17 +155,18 @@ sub recent {
 }
 
 sub all {
-    my $self = shift;
-    my $type = shift;
+    my $self   = shift;
+    my $type   = shift;
+    my $params = shift;
 
-    my $match_all = { __MATCH_ALL__ => 1 };
+    grep { $type eq $_ } qw/ authors distributions modules releases /
+        or croak "all: unsupported type";
+    $type =~ s/s$//;
 
-    $type eq 'authors'       and return $self->author( $match_all );
-    $type eq 'distributions' and return $self->distribution( $match_all );
-    $type eq 'modules'       and return $self->module( $match_all );
-    $type eq 'releases'      and return $self->release( $match_all );
+    $params and ref($params) ne 'HASH'
+        and croak "all: params must be a hashref";
 
-    croak "all: unsupported type";
+    return $self->$type( { __MATCH_ALL__ => 1 }, $params );
 }
 
 ###
@@ -343,7 +344,7 @@ MetaCPAN::Client - A comprehensive, DWIM-featured client to the MetaCPAN API
 
 =head1 VERSION
 
-version 1.009000
+version 1.010000
 
 =head1 SYNOPSIS
 
@@ -493,6 +494,22 @@ Retrieve all matches for authors/modules/distributions or releases.
 
     my $all_releases = $mcpan->all('releases')
 
+When called with a second parameter containing a hash ref,
+will support the following keys:
+
+=head3 fields
+
+See SEARCH PARAMS.
+
+   my $all_releases = $mcpan->all('releases', { fields => [...] })
+
+=head3 es_filter
+
+Pass a raw ElasticSearch filter structure to reduce the number
+of elements returned by the query.
+
+    my $some_releases = $mcpan->all('releases', { es_filter => {...} })
+
 =head2 BUILDARGS
 
 Internal construction wrapper. Do not use.
